@@ -262,9 +262,13 @@ class dyn_obj:
 
         int_curveOB.data.bevel_depth = thickness
 
+        bpy.data.objects[name].data.bevel_factor_mapping_end = "SEGMENTS"
+        bpy.data.objects[name].data.bevel_factor_mapping_start = "SEGMENTS"
 
         if staticity == 'dynamic':
             for i in range(len(frames)):
+                cur_frame = frames[i]
+
                 bpy.data.objects[name].data.bevel_factor_end = self.arc_length_frac[i]
                 bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
             
